# Kavian Info

## Instructions

Follow these instructions to keep going

First you can get to know me by calling `kavian_info` function

```python
from package_test import info

info.kavian_info()
"Hello, My name is Kavian and I'm currently 26 years old"
```

After know me, you can chat with me too:

```python
from package_test import info

info.greet('Salam Kiara')
'Hello kiara Welcome'

info.greet('bye')
'Bye'
```
